+++
title = "ox-hugo Issue 360 test (Regular)"
description = "Link to image using `file:` in a Regular page."
tags = ["issues", "images", "figure"]
draft = false
+++

`ox-hugo` Issue #[360](https://github.com/kaushalmodi/ox-hugo/issues/360)

{{< figure src="/ox-hugo/org.png" >}}
